@@ -31,11 +31,13 @@ from naas_drivers.inputOutput.notion import Notion
 from naas_drivers.inputOutput.hubspot import Hubspot
 from naas_drivers.inputOutput.thinkific import Thinkific
 from naas_drivers.input.markdown import Markdown
+from naas_drivers.output.streamlit import NaasStreamlit
+from naas_drivers.input.nlp import NLP
 
 import requests
 import os
 
-__version__ = "0.55.0"
+__version__ = "0.58.0"
 
 __github_repo = "jupyter-naas/drivers"
 
@@ -60,6 +62,7 @@ markdown = Markdown()
 teams = Teams()
 slack = Slack()
 qonto = Qonto()
+nlp = NLP()
 
 # Out drivers
 bubble = Bubble()
@@ -82,6 +85,7 @@ toucan = Toucan()
 linkedin = LinkedIn()
 hubspot = Hubspot()
 thinkific = Thinkific()
+streamlit = NaasStreamlit()
 
 __doc_url = "https://naas.gitbook.io/drivers/"
 
