@@ -3,9 +3,15 @@ import requests
 
 
 class Zappier(OutDriver):
-    def webhook(self, url, data=None):
+    def connect(self, url):
+        self._key = url
+        self.connected = True
+        return self
+
+    def send(self, data=None):
+        self.check_connect()
         r = requests.post(
-            url=url,
+            url=self._key,
             json=data,
         )
         r.raise_for_status()
